# Generated by Django 6.0.1 on 2026-01-13 10:12

import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Attachment',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('original_name', models.CharField(max_length=255)),
                ('storage_path', models.CharField(max_length=500)),
                ('mime_type', models.CharField(max_length=100)),
                ('size', models.BigIntegerField()),
                ('owner_id', models.CharField(db_index=True, max_length=100)),
                ('is_public', models.BooleanField(db_index=True, default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True, db_index=True)),
            ],
            options={
                'db_table': 'chewy_attachment_files',
                'ordering': ['-created_at'],
                'indexes': [models.Index(fields=['owner_id', 'created_at'], name='chewy_attac_owner_i_9ee24d_idx')],
            },
        ),
    ]
